@@ -153,6 +153,7 @@ class RegistryHive:
                                                     path_root=subkey_path,
                                                     as_json=as_json,
                                                     is_init=False)
+
                 values = []
                 if subkey.values_count:
                     try:
@@ -293,12 +294,14 @@ class NKRecord:
         self.header = CM_KEY_NODE.parse_stream(stream)
         self._stream = stream
 
-        # Sometime the values are utf-8 and sometimes utf-16 little endian, we attempt both
-        try:
-            decoded_name = self.header.key_name_string.decode()
-        except UnicodeDecodeError:
-            decoded_name = self.header.key_name_string.decode('utf-16-le', errors='replace')
-        self.name = decoded_name
+        # Sometimes the key names are ASCII and sometimes UTF-16 little endian
+        if self.header.flags.KEY_COMP_NAME:
+            # Compressed (ASCII) key name
+            self.name = self.header.key_name_string.decode('ascii', errors='replace')
+        else:
+            # Unicode (UTF-16) key name
+            self.name = self.header.key_name_string.decode('utf-16-le', errors='replace')
+            logger.debug(f'Unicode key name identified: "{self.name}"')
 
         self.subkey_count = self.header.subkey_count
         self.values_count = self.header.values_count
@@ -442,23 +445,30 @@ class NKRecord:
 
                 if vk.name_size == 0:
                     value_name = '(default)'
+                elif vk.flags.VALUE_COMP_NAME:
+                    # Compressed (ASCII) value name
+                    value_name = vk.name.decode('ascii', errors='replace')
                 else:
-                    value_name = vk.name.decode(errors='replace')
+                    # Unicode (UTF-16) value name
+                    value_name = vk.name.decode('utf-16-le', errors='replace')
+                    logger.debug(f'Unicode value name identified: "{value_name}"')
 
                 # If the value is bigger than this value, it means this is a DEVPROP structure
                 # https://doxygen.reactos.org/d0/dba/devpropdef_8h_source.html
                 # https://sourceforge.net/p/mingw-w64/mingw-w64/ci/668a1d3e85042c409e0c292e621b3dc0aa26177c/tree/
                 # mingw-w64-headers/include/devpropdef.h?diff=dd86a3b7594dadeef9d6a37c4b6be3ca42ef7e94
-                # We currently do not support these, but also wouldn't like to yield this as binary data
+                # We currently do not support these, We are going to make the best effort to dump as string.
                 # This int casting will always work because the data_type is construct's EnumIntegerString
-                # TODO: Add actual parsing
                 if int(vk.data_type) > 0xffff0000:
+                    logger.info(f"Value at {hex(actual_vk_offset)} contains DEVPROP structure")
+                    # TODO: Add a test for an existing hive with devprop, verify we handle it
                     data_type = int(vk.data_type) & 0xffff
-                    continue
+                    actual_value = try_decode_binary(value.value, as_json=as_json)
 
                 # Skip this unknown data type, research pending :)
                 # TODO: Add actual parsing
-                if int(vk.data_type) == 0x200000:
+                elif int(vk.data_type) == 0x200000:
+                    logger.info(f"Skipped unknown data type value at {actual_vk_offset}")
                     continue
 
                 data_type = str(vk.data_type)
@@ -559,6 +569,19 @@ class NKRecord:
                 'sacl': sacl_aces
             }
 
+    def get_class_name(self) -> str:
+        """
+        Gets the key class name as would be returned via
+        the `lpClass` argument of the `RegQueryInfoKey()` function.
+        """
+
+        # Get the offset of the class name string. We skip 4 because of Cell Header
+        read_offset = REGF_HEADER_SIZE + 4 + self.header.class_name_offset
+
+        self._stream.seek(read_offset)
+        class_name = self._stream.read(self.header.class_name_size)
+
+        return class_name.decode('utf-16-le', errors='replace')
 
     def __dict__(self):
         return {
